# proton_api
Financial engineering module of Hydrogen Atom

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.8.0
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.hydrogenplatform.com/contact](https://www.hydrogenplatform.com/contact)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage

### Update Base Path
Follow steps to verify the base URL path:
1. Go to configuration.py file located under proton_api folder.
2. Search for self.host and change/verify the URL according to the environment.
**Sandbox Base URL**
https://sandbox.hydrogenplatform.com/proton/v1
**Production Base URL**
https://api.hydrogenplatform.com/proton/v1

### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com//.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com//.git`)

Then import the package:
```python
import proton_api 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import proton_api
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import proton_api
from proton_api.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: oauth2
configuration = proton_api.Configuration()

# create an instance of the API class
api_instance = proton_api.AuthApi(proton_api.ApiClient(configuration))

#api_token_response = api_instance.create_using_post_client_credentials("client_id", "password")

# OR

#api_token_response = api_instance.create_using_post_password_credentials("client_id","password", "username", "secret" )
# OR

# api_token_response = api_instance.create_client_token_credentials("client_id", "password", "client_token");

configuration.access_token = api_token_response.access_token

# create an instance of the API class
api_instance = proton_api.AnnuitiesApi(proton_api.ApiClient(configuration))
annuity_calculator_accumulation_horizon_request = proton_api.AnnuityCalculatorAccumulationHorizonRequest() # AnnuityCalculatorAccumulationHorizonRequest | Request payload for Annuity Calculator - Accumulation Horizon

try:
    # Annuity Calculator - Accumulation Horizon
    api_response = api_instance.annuity_calculator_accumulation_horizon(annuity_calculator_accumulation_horizon_request)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AnnuitiesApi->annuity_calculator_accumulation_horizon: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://sandbox.hydrogenplatform.com/proton/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AnnuitiesApi* | [**annuity_calculator_accumulation_horizon**](docs/AnnuitiesApi.md#annuity_calculator_accumulation_horizon) | **POST** /annuity_calculator/accumulation_horizon | Annuity Calculator - Accumulation Horizon
*AnnuitiesApi* | [**annuity_calculator_annuity_amount**](docs/AnnuitiesApi.md#annuity_calculator_annuity_amount) | **POST** /annuity_calculator/annuity_amount | Annuity Calculator - Annuity Amount
*AnnuitiesApi* | [**annuity_calculator_decumulation_horizon**](docs/AnnuitiesApi.md#annuity_calculator_decumulation_horizon) | **POST** /annuity_calculator/decumulation_horizon | Annuity Calculator - Decumulation Horizon
*AnnuitiesApi* | [**annuity_calculator_deposit_amount**](docs/AnnuitiesApi.md#annuity_calculator_deposit_amount) | **POST** /annuity_calculator/deposit_amount | Annuity Calculator - Deposit Amount
*AnnuitiesApi* | [**annuity_calculator_initial_balance**](docs/AnnuitiesApi.md#annuity_calculator_initial_balance) | **POST** /annuity_calculator/initial_balance | Annuity Calculator - Initial Balance
*AnnuitiesApi* | [**variable_annuity**](docs/AnnuitiesApi.md#variable_annuity) | **POST** /variable_annuity | Variable Annuity
*BusinessFinancialManagementApi* | [**business_financial_health_check**](docs/BusinessFinancialManagementApi.md#business_financial_health_check) | **POST** /business/financial_health_check | Business Financial Health Check
*BusinessFinancialManagementApi* | [**cash_analysis**](docs/BusinessFinancialManagementApi.md#cash_analysis) | **POST** /business/cash_analysis | Cash Analysis
*BusinessFinancialManagementApi* | [**customer_analysis**](docs/BusinessFinancialManagementApi.md#customer_analysis) | **POST** /business/customer_analysis | Customer Analysis
*BusinessFinancialManagementApi* | [**financial_statement_analysis**](docs/BusinessFinancialManagementApi.md#financial_statement_analysis) | **POST** /business/financial_statement_analysis | Financial Statement Analysis
*BusinessFinancialManagementApi* | [**invoice_analysis**](docs/BusinessFinancialManagementApi.md#invoice_analysis) | **POST** /business/invoice_analysis | Invoice Analysis
*CardsApi* | [**card_limit_check**](docs/CardsApi.md#card_limit_check) | **POST** /card_limit_check | Card Limit Check
*CardsApi* | [**card_transaction_authorization**](docs/CardsApi.md#card_transaction_authorization) | **POST** /card_authorization | Card Transaction Authorization
*FinancialHealthApi* | [**diversification_score**](docs/FinancialHealthApi.md#diversification_score) | **POST** /diversification_score | Diversification Score
*FinancialHealthApi* | [**emergency_fund_calculator**](docs/FinancialHealthApi.md#emergency_fund_calculator) | **POST** /emergency_fund_calculator | Emergency Fund Calculator
*FinancialHealthApi* | [**financial_health_check**](docs/FinancialHealthApi.md#financial_health_check) | **POST** /financial_health_check | Financial Health Check
*FinancialHealthApi* | [**portfolio_optimization_score**](docs/FinancialHealthApi.md#portfolio_optimization_score) | **POST** /portfolio_optimization_score | Portfolio Optimization Score
*FinancialPlanningApi* | [**education_calculator_annual_cost**](docs/FinancialPlanningApi.md#education_calculator_annual_cost) | **POST** /education_calculator/annual_cost | Education Calculator - Annual Cost
*FinancialPlanningApi* | [**education_calculator_deposit_amount**](docs/FinancialPlanningApi.md#education_calculator_deposit_amount) | **POST** /education_calculator/deposit_amount | Education Calculator - Deposit Amount
*FinancialPlanningApi* | [**education_calculator_percent_covered**](docs/FinancialPlanningApi.md#education_calculator_percent_covered) | **POST** /education_calculator/percent_covered | Education Calculator - Percent Covered
*FinancialPlanningApi* | [**mortgage_calculator_down_payment**](docs/FinancialPlanningApi.md#mortgage_calculator_down_payment) | **POST** /mortgage_calculator/down_payment | Mortgage Calculator - Down Payment
*FinancialPlanningApi* | [**mortgage_calculator_home_price**](docs/FinancialPlanningApi.md#mortgage_calculator_home_price) | **POST** /mortgage_calculator/home_price | Mortgage Calculator - Home Price
*FinancialPlanningApi* | [**mortgage_calculator_periodic_payment**](docs/FinancialPlanningApi.md#mortgage_calculator_periodic_payment) | **POST** /mortgage_calculator/periodic_payment | Mortgage Calculator - Periodic Payment
*FinancialPlanningApi* | [**purchase_calculator_amount**](docs/FinancialPlanningApi.md#purchase_calculator_amount) | **POST** /purchase_calculator/amount | Purchase Calculator - Amount
*FinancialPlanningApi* | [**purchase_calculator_deposit_amount**](docs/FinancialPlanningApi.md#purchase_calculator_deposit_amount) | **POST** /purchase_calculator/deposit_amount | Purchase Calculator - Deposit Amount
*FinancialPlanningApi* | [**purchase_calculator_horizon**](docs/FinancialPlanningApi.md#purchase_calculator_horizon) | **POST** /purchase_calculator/horizon | Purchase Calculator - Horizon
*FinancialPlanningApi* | [**retirement_calculator_deposit_amount**](docs/FinancialPlanningApi.md#retirement_calculator_deposit_amount) | **POST** /retirement_calculator/deposit_amount | Retirement Calculator - Deposit Amount
*FinancialPlanningApi* | [**retirement_calculator_expenses**](docs/FinancialPlanningApi.md#retirement_calculator_expenses) | **POST** /retirement_calculator/expenses | Retirement Calculator - Expenses
*FinancialPlanningApi* | [**retirement_calculator_percent_covered**](docs/FinancialPlanningApi.md#retirement_calculator_percent_covered) | **POST** /retirement_calculator/percent_covered | Retirement Calculator - Percent Covered
*GoalsApi* | [**goal_accumulation_allocation**](docs/GoalsApi.md#goal_accumulation_allocation) | **POST** /goal_accumulation/allocation | Goal Accumulation Allocation
*GoalsApi* | [**goal_accumulation_recommendation**](docs/GoalsApi.md#goal_accumulation_recommendation) | **POST** /goal_accumulation/recommendation | Goal Accumulation Recommendation
*GoalsApi* | [**goal_accumulation_status**](docs/GoalsApi.md#goal_accumulation_status) | **POST** /goal_accumulation/status | Goal Accumulation Status
*GoalsApi* | [**goal_decumulation_allocation**](docs/GoalsApi.md#goal_decumulation_allocation) | **POST** /goal_decumulation/allocation | Goal Decumulation Allocation
*GoalsApi* | [**goal_decumulation_recommendation**](docs/GoalsApi.md#goal_decumulation_recommendation) | **POST** /goal_decumulation/recommendation | Goal Decumulation Recommendation
*GoalsApi* | [**goal_decumulation_status**](docs/GoalsApi.md#goal_decumulation_status) | **POST** /goal_decumulation/status | Goal Decumulation Status
*LifeInsuranceApi* | [**life_insurance_needs_calculator**](docs/LifeInsuranceApi.md#life_insurance_needs_calculator) | **POST** /life_insurance/needs_calculator | Life Insurance Needs Calculator
*PersonalFinancialManagementApi* | [**budget_calculator**](docs/PersonalFinancialManagementApi.md#budget_calculator) | **POST** /budget_calculator | Budget Calculator
*PersonalFinancialManagementApi* | [**cash_flow_analysis**](docs/PersonalFinancialManagementApi.md#cash_flow_analysis) | **POST** /cash_flow_analysis | Cash Flow Analysis
*PersonalFinancialManagementApi* | [**fee_analysis**](docs/PersonalFinancialManagementApi.md#fee_analysis) | **POST** /fee_analysis | RFee Analysis
*PersonalFinancialManagementApi* | [**financial_picture**](docs/PersonalFinancialManagementApi.md#financial_picture) | **POST** /financial_picture | Financial Picture
*PersonalFinancialManagementApi* | [**recurring_transaction_analysis**](docs/PersonalFinancialManagementApi.md#recurring_transaction_analysis) | **POST** /recurring_transaction_analysis | Recurring Transaction Analysis
*PortfolioConstructionApi* | [**mvo**](docs/PortfolioConstructionApi.md#mvo) | **POST** /mvo | MVO
*PortfolioManagementApi* | [**rebalancing_signal**](docs/PortfolioManagementApi.md#rebalancing_signal) | **POST** /rebalancing_signal | Rebalancing Signal
*RiskScoringApi* | [**dimensional_risk_score**](docs/RiskScoringApi.md#dimensional_risk_score) | **POST** /dimensional_risk_score | Dimensional Risk Score
*RiskScoringApi* | [**risk_allocation**](docs/RiskScoringApi.md#risk_allocation) | **POST** /risk_allocation | Risk Allocation
*RiskScoringApi* | [**risk_score**](docs/RiskScoringApi.md#risk_score) | **POST** /risk_score | Risk Score
*SimulationsApi* | [**backtest**](docs/SimulationsApi.md#backtest) | **POST** /backtest | Backtest
*SimulationsApi* | [**event_study**](docs/SimulationsApi.md#event_study) | **POST** /event_study | Event Study
*SimulationsApi* | [**monte_carlo**](docs/SimulationsApi.md#monte_carlo) | **POST** /monte_carlo | Monte Carlo
*SimulationsApi* | [**portfolio_what_if**](docs/SimulationsApi.md#portfolio_what_if) | **POST** /portfolio_what_if | Porfolio What-If
*SimulationsApi* | [**savings_calculator**](docs/SimulationsApi.md#savings_calculator) | **POST** /savings_calculator | Savings Calculator
*SimulationsApi* | [**scenario_analysis**](docs/SimulationsApi.md#scenario_analysis) | **POST** /scenario_analysis | Scenario Analysis
*SimulationsApi* | [**sensitivity_analysis**](docs/SimulationsApi.md#sensitivity_analysis) | **POST** /sensitivity_analysis | Sensitivity Analysis


## Documentation For Models

 - [AccumulationGoalDepositConfig](docs/AccumulationGoalDepositConfig.md)
 - [AnnuityCalculatorAccumulationHorizonRequest](docs/AnnuityCalculatorAccumulationHorizonRequest.md)
 - [AnnuityCalculatorAnnuityAmountRequest](docs/AnnuityCalculatorAnnuityAmountRequest.md)
 - [AnnuityCalculatorDecumulationHorizonRequest](docs/AnnuityCalculatorDecumulationHorizonRequest.md)
 - [AnnuityCalculatorDepositAmountRequest](docs/AnnuityCalculatorDepositAmountRequest.md)
 - [AnnuityCalculatorInitialBalanceRequest](docs/AnnuityCalculatorInitialBalanceRequest.md)
 - [AnnuityDepositSchedule](docs/AnnuityDepositSchedule.md)
 - [BacktestRequest](docs/BacktestRequest.md)
 - [BeneficiaryBequestConfig](docs/BeneficiaryBequestConfig.md)
 - [BudgetAggregationAccount](docs/BudgetAggregationAccount.md)
 - [BudgetCalculatorRequest](docs/BudgetCalculatorRequest.md)
 - [BudgetComponent](docs/BudgetComponent.md)
 - [BudgetDetails](docs/BudgetDetails.md)
 - [BusinessFinancialHealthCheckRequest](docs/BusinessFinancialHealthCheckRequest.md)
 - [BusinessInvoiceAnalysisRequest](docs/BusinessInvoiceAnalysisRequest.md)
 - [CalculatorDepositSchedule](docs/CalculatorDepositSchedule.md)
 - [CalculatorDepositSchedule1](docs/CalculatorDepositSchedule1.md)
 - [CardLimitCheckRequest](docs/CardLimitCheckRequest.md)
 - [CardTransactionAuthorizationRequest](docs/CardTransactionAuthorizationRequest.md)
 - [CashAnalysisRequest](docs/CashAnalysisRequest.md)
 - [CashFlowAnalysisRequest](docs/CashFlowAnalysisRequest.md)
 - [ChildrenEducationConfig](docs/ChildrenEducationConfig.md)
 - [CustomerAnalysisRequest](docs/CustomerAnalysisRequest.md)
 - [DecumulationGoalDepositConfig](docs/DecumulationGoalDepositConfig.md)
 - [DimensionalRiskScoreRequest](docs/DimensionalRiskScoreRequest.md)
 - [DiversificationScoreRequest](docs/DiversificationScoreRequest.md)
 - [EducationCalculatorAnnualCostRequest](docs/EducationCalculatorAnnualCostRequest.md)
 - [EducationCalculatorDepositAmountRequest](docs/EducationCalculatorDepositAmountRequest.md)
 - [EducationCalculatorPercentCoveredRequest](docs/EducationCalculatorPercentCoveredRequest.md)
 - [EducationConfig](docs/EducationConfig.md)
 - [EmergencyFundCalculatorRequest](docs/EmergencyFundCalculatorRequest.md)
 - [EventStudyRequest](docs/EventStudyRequest.md)
 - [FeeAnalysisRequest](docs/FeeAnalysisRequest.md)
 - [FinancialHealthCheckRequest](docs/FinancialHealthCheckRequest.md)
 - [FinancialPictureRequest](docs/FinancialPictureRequest.md)
 - [FinancialStatementAnalysisRequest](docs/FinancialStatementAnalysisRequest.md)
 - [GoalAccumulationAllocationRequest](docs/GoalAccumulationAllocationRequest.md)
 - [GoalAccumulationRecommendationRequest](docs/GoalAccumulationRecommendationRequest.md)
 - [GoalAccumulationStatusRequest](docs/GoalAccumulationStatusRequest.md)
 - [GoalConfig](docs/GoalConfig.md)
 - [GoalDecumulationAllocationRequest](docs/GoalDecumulationAllocationRequest.md)
 - [GoalDecumulationRecommendationRequest](docs/GoalDecumulationRecommendationRequest.md)
 - [GoalDecumulationStatusRequest](docs/GoalDecumulationStatusRequest.md)
 - [GoalWithdrawalConfig](docs/GoalWithdrawalConfig.md)
 - [GuaranteedRateBenefit](docs/GuaranteedRateBenefit.md)
 - [IncomeConfig](docs/IncomeConfig.md)
 - [LifeInsuranceNeedsCalculatorRequest](docs/LifeInsuranceNeedsCalculatorRequest.md)
 - [MonteCarloRequest](docs/MonteCarloRequest.md)
 - [MortgageCalculatorDownPaymentRequest](docs/MortgageCalculatorDownPaymentRequest.md)
 - [MortgageCalculatorHomePriceRequest](docs/MortgageCalculatorHomePriceRequest.md)
 - [MortgageCalculatorPeriodicPaymentRequest](docs/MortgageCalculatorPeriodicPaymentRequest.md)
 - [MvoRequest](docs/MvoRequest.md)
 - [OptConfig](docs/OptConfig.md)
 - [OptConfig1](docs/OptConfig1.md)
 - [Periods](docs/Periods.md)
 - [PortfolioOptimizationScoreRequest](docs/PortfolioOptimizationScoreRequest.md)
 - [PortfolioWhatIfRequest](docs/PortfolioWhatIfRequest.md)
 - [PurchaseCalculatorAmountRequest](docs/PurchaseCalculatorAmountRequest.md)
 - [PurchaseCalculatorDepositAmountRequest](docs/PurchaseCalculatorDepositAmountRequest.md)
 - [PurchaseCalculatorHorizonRequest](docs/PurchaseCalculatorHorizonRequest.md)
 - [RatioTargets](docs/RatioTargets.md)
 - [RatioTargets1](docs/RatioTargets1.md)
 - [RebalancingSignalRequest](docs/RebalancingSignalRequest.md)
 - [RecommendationConfig](docs/RecommendationConfig.md)
 - [RecommendationConfig1](docs/RecommendationConfig1.md)
 - [RecurringTransactionAnalysisRequest](docs/RecurringTransactionAnalysisRequest.md)
 - [RetirementCalculatorDepositAmountRequest](docs/RetirementCalculatorDepositAmountRequest.md)
 - [RetirementCalculatorExpensesRequest](docs/RetirementCalculatorExpensesRequest.md)
 - [RetirementCalculatorPercentCoveredRequest](docs/RetirementCalculatorPercentCoveredRequest.md)
 - [RiskAllocationRequest](docs/RiskAllocationRequest.md)
 - [RiskScoreRequest](docs/RiskScoreRequest.md)
 - [SavingsCalculatorRequest](docs/SavingsCalculatorRequest.md)
 - [SavingsDepositSchedule](docs/SavingsDepositSchedule.md)
 - [ScenarioAnalysisRequest](docs/ScenarioAnalysisRequest.md)
 - [SensitivityAnalysisRequest](docs/SensitivityAnalysisRequest.md)
 - [SensitivityFactor](docs/SensitivityFactor.md)
 - [Settings](docs/Settings.md)
 - [VariableAnnuityRequest](docs/VariableAnnuityRequest.md)
 - [WConfig](docs/WConfig.md)
 - [WConfig1](docs/WConfig1.md)


## Documentation For Authorization


## oauth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Author

info@hydrogenplatform.com

